@@ -79,6 +79,7 @@ AbstractModel::fstau(realtype* /*stau*/,
                      const realtype* /*p*/,
                      const realtype* /*k*/,
                      const realtype* /*h*/,
+                     const realtype* /*tcl*/,
                      const realtype* /*sx*/,
                      const int /*ip*/,
                      const int /*ie*/)
@@ -118,6 +119,17 @@ AbstractModel::fdydp(realtype* /*dydp*/,
                        __func__);
 }
 
+void AbstractModel::fdydp(realtype */*dydp*/, const realtype /*t*/,
+                          const realtype */*x*/, const realtype */*p*/,
+                          const realtype */*k*/, const realtype */*h*/,
+                          int /*ip*/, const realtype */*w*/,
+                          const realtype */*tcl*/, const realtype */*dtcldp*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
 void
 AbstractModel::fdydx(realtype* /*dydx*/,
                      const realtype /*t*/,
@@ -280,7 +292,8 @@ AbstractModel::fdeltasx(realtype* /*deltasx*/,
                         const realtype* /*xdot*/,
                         const realtype* /*xdot_old*/,
                         const realtype* /*sx*/,
-                        const realtype* /*stau*/)
+                        const realtype* /*stau*/,
+                        const realtype* /*tcl*/)
 {
     throw AmiException("Requested functionality is not supported as %s is "
                        "not implemented for this model!",
@@ -326,7 +339,8 @@ void
 AbstractModel::fsigmay(realtype* /*sigmay*/,
                        const realtype /*t*/,
                        const realtype* /*p*/,
-                       const realtype* /*k*/)
+                       const realtype* /*k*/,
+                       const realtype */*y*/)
 {
     throw AmiException("Requested functionality is not supported as %s is "
                        "not implemented for this model!",
@@ -338,6 +352,7 @@ AbstractModel::fdsigmaydp(realtype* /*dsigmaydp*/,
                           const realtype /*t*/,
                           const realtype* /*p*/,
                           const realtype* /*k*/,
+                          const realtype */*y*/,
                           const int /*ip*/)
 {
     throw AmiException("Requested functionality is not supported as %s is "
@@ -345,6 +360,18 @@ AbstractModel::fdsigmaydp(realtype* /*dsigmaydp*/,
                        __func__);
 }
 
+void
+AbstractModel::fdsigmaydy(realtype */*dsigmaydy*/,
+                          const realtype /*t*/,
+                          const realtype */*p*/,
+                          const realtype */*k*/,
+                          const realtype */*y*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
 void
 AbstractModel::fsigmaz(realtype* /*sigmaz*/,
                        const realtype /*t*/,
@@ -627,4 +654,97 @@ void AbstractModel::fdwdw_rowvals(SUNMatrixWrapper &/*dwdw*/) {
                        __func__);
 }
 
+void AbstractModel::fdx_rdatadx_solver(realtype */*dx_rdatadx_solver*/,
+                               const realtype */*x*/, const realtype */*tcl*/,
+                               const realtype */*p*/, const realtype */*k*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdx_rdatadx_solver_rowvals(SUNMatrixWrapper &/*dxrdxs*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdx_rdatadx_solver_colptrs(SUNMatrixWrapper &/*dxrdxs*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdx_rdatadp(realtype */*dx_rdatadp*/, const realtype */*x*/,
+                        const realtype */*tcl*/, const realtype */*p*/,
+                        const realtype */*k*/, const int /*ip*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdx_rdatadtcl(realtype */*dx_rdatadtcl*/, const realtype */*x*/,
+                          const realtype */*tcl*/, const realtype */*p*/,
+                          const realtype */*k*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdx_rdatadtcl_rowvals(SUNMatrixWrapper &/*dxrdtcl*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdx_rdatadtcl_colptrs(SUNMatrixWrapper &/*dxrdtcl*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdtotal_cldp(realtype */*dtotal_cldp*/,
+                                const realtype */*x_rdata*/,
+                                const realtype */*p*/,
+                                const realtype */*k*/,
+                                const int /*ip*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdtotal_cldx_rdata(realtype */*dtotal_cldx_rdata*/,
+                                      const realtype */*x_rdata*/,
+                                      const realtype */*p*/,
+                                      const realtype */*k*/,
+                                      const realtype */*tcl*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdtotal_cldx_rdata_colptrs(
+    SUNMatrixWrapper &/*dtotal_cldx_rdata*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
+void AbstractModel::fdtotal_cldx_rdata_rowvals(
+    SUNMatrixWrapper &/*dtotal_cldx_rdata*/)
+{
+    throw AmiException("Requested functionality is not supported as %s is "
+                       "not implemented for this model!",
+                       __func__);
+}
+
 } // namespace amici
